@@ -1,6 +1,6 @@
-# -*- ruby encoding: utf-8 -*-
+# frozen_string_literal: true
 
-require 'spec_helper'
+require "spec_helper"
 
 describe "Diff::LCS.patch" do
   include Diff::LCS::SpecHelper::Matchers
@@ -29,12 +29,12 @@ describe "Diff::LCS.patch" do
     describe "an empty patchset returns the source" do
       it "works on a string (hello)" do
         diff = Diff::LCS.diff(hello, hello)
-        expect(Diff::LCS::patch(hello, diff)).to eq(hello)
+        expect(Diff::LCS.patch(hello, diff)).to eq(hello)
       end
 
       it "works on an array %W(h e l l o)" do
         diff = Diff::LCS.diff(hello_ary, hello_ary)
-        expect(Diff::LCS::patch(hello_ary, diff)).to eq(hello_ary)
+        expect(Diff::LCS.patch(hello_ary, diff)).to eq(hello_ary)
       end
     end
 
@@ -104,11 +104,11 @@ describe "Diff::LCS.patch" do
   describe "using a Diff::LCS.sdiff patchset" do
     describe "an empty patchset returns the source" do
       it "works on a string (hello)" do
-        expect(Diff::LCS::patch(hello, Diff::LCS.sdiff(hello, hello))).to eq(hello)
+        expect(Diff::LCS.patch(hello, Diff::LCS.sdiff(hello, hello))).to eq(hello)
       end
 
       it "works on an array %W(h e l l o)" do
-        expect(Diff::LCS::patch(hello_ary, Diff::LCS.sdiff(hello_ary, hello_ary))).to eq(hello_ary)
+        expect(Diff::LCS.patch(hello_ary, Diff::LCS.sdiff(hello_ary, hello_ary))).to eq(hello_ary)
       end
     end
 
@@ -181,8 +181,8 @@ describe "Diff::LCS.patch" do
   # above.
   describe "fix bug 891: patchsets do not contain the last equal part" do
     before :each do
-      @s1 = %w(a b c d   e f g h i j k)
-      @s2 = %w(a b c d D e f g h i j k)
+      @s1 = %w[a b c d   e f g h i j k] # rubocop:disable Layout/SpaceInsideArrayPercentLiteral
+      @s2 = %w[a b c d D e f g h i j k]
     end
 
     describe "using Diff::LCS.diff with default diff callbacks" do
@@ -225,10 +225,8 @@ describe "Diff::LCS.patch" do
 
     describe "using Diff::LCS.diff with context diff callbacks" do
       before :each do
-        @patch_set_s1_s2 = Diff::LCS.diff(@s1, @s2,
-                                          Diff::LCS::ContextDiffCallbacks)
-        @patch_set_s2_s1 = Diff::LCS.diff(@s2, @s1,
-                                          Diff::LCS::ContextDiffCallbacks)
+        @patch_set_s1_s2 = Diff::LCS.diff(@s1, @s2, Diff::LCS::ContextDiffCallbacks)
+        @patch_set_s2_s1 = Diff::LCS.diff(@s2, @s1, Diff::LCS::ContextDiffCallbacks)
       end
 
       it "autodiscovers s1 to s2 patches" do
@@ -265,10 +263,8 @@ describe "Diff::LCS.patch" do
 
     describe "using Diff::LCS.diff with sdiff callbacks" do
       before(:each) do
-        @patch_set_s1_s2 = Diff::LCS.diff(@s1, @s2,
-                                          Diff::LCS::SDiffCallbacks)
-        @patch_set_s2_s1 = Diff::LCS.diff(@s2, @s1,
-                                          Diff::LCS::SDiffCallbacks)
+        @patch_set_s1_s2 = Diff::LCS.diff(@s1, @s2, Diff::LCS::SDiffCallbacks)
+        @patch_set_s2_s1 = Diff::LCS.diff(@s2, @s1, Diff::LCS::SDiffCallbacks)
       end
 
       it "autodiscovers s1 to s2 patches" do
@@ -343,10 +339,8 @@ describe "Diff::LCS.patch" do
 
     describe "using Diff::LCS.sdiff with context diff callbacks" do
       before(:each) do
-        @patch_set_s1_s2 = Diff::LCS.sdiff(@s1, @s2,
-                                           Diff::LCS::ContextDiffCallbacks)
-        @patch_set_s2_s1 = Diff::LCS.sdiff(@s2, @s1,
-                                           Diff::LCS::ContextDiffCallbacks)
+        @patch_set_s1_s2 = Diff::LCS.sdiff(@s1, @s2, Diff::LCS::ContextDiffCallbacks)
+        @patch_set_s2_s1 = Diff::LCS.sdiff(@s2, @s1, Diff::LCS::ContextDiffCallbacks)
       end
 
       it "autodiscovers s1 to s2 patches" do
